@@ -6,10 +6,12 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from .aioprotocol import AIOLEDENETProtocol
 from .aioscanner import AIOBulbScanner
+from .aioutils import asyncio_timeout
 from .base_device import (
     ALL_ADDRESSABLE_PROTOCOLS,
     ALL_IC_PROTOCOLS,
     DeviceType,
+    DeviceUnavailableException,
     LEDENETDevice,
 )
 from .const import (
@@ -66,7 +68,7 @@ class AIOWifiLedBulb(LEDENETDevice):
         self,
         ipaddr: str,
         port: int = 0,
-        timeout: float = 5,
+        timeout: float = 7.5,
         discovery: Optional[FluxLEDDiscovery] = None,
     ) -> None:
         """Init and setup the bulb."""
@@ -133,7 +135,8 @@ class AIOWifiLedBulb(LEDENETDevice):
         assert self._protocol is not None
         await self._async_send_msg(self._protocol.construct_query_remote_config())
         try:
-            await asyncio.wait_for(self._remote_config_future, timeout=self.timeout)
+            async with asyncio_timeout(self.timeout):
+                await self._remote_config_future
         except asyncio.TimeoutError:
             _LOGGER.warning("%s: Could not determine 2.4ghz remote config", self.ipaddr)
 
@@ -142,10 +145,11 @@ class AIOWifiLedBulb(LEDENETDevice):
         assert self._protocol is not None
         await self._async_send_msg(self._protocol.construct_power_restore_state_query())
         try:
-            await asyncio.wait_for(self._power_restore_future, timeout=self.timeout)
+            async with asyncio_timeout(self.timeout):
+                await self._power_restore_future
         except asyncio.TimeoutError:
-            self.set_unavailable()
-            raise RuntimeError(
+            self.set_unavailable("Could not determine power restore state")
+            raise DeviceUnavailableException(
                 f"{self.ipaddr}: Could not determine power restore state"
             )
 
@@ -163,10 +167,13 @@ class AIOWifiLedBulb(LEDENETDevice):
         assert isinstance(self._protocol, ALL_ADDRESSABLE_PROTOCOLS)
         await self._async_send_msg(self._protocol.construct_request_strip_setting())
         try:
-            await asyncio.wait_for(self._device_config_future, timeout=self.timeout)
+            async with asyncio_timeout(self.timeout):
+                await self._device_config_future
         except asyncio.TimeoutError:
-            self.set_unavailable()
-            raise RuntimeError(f"{self.ipaddr}: Could not determine number pixels")
+            self.set_unavailable("Could not determine number pixels")
+            raise DeviceUnavailableException(
+                f"{self.ipaddr}: Could not determine number pixels"
+            )
 
     async def async_stop(self) -> None:
         """Shutdown the connection."""
@@ -174,7 +181,7 @@ class AIOWifiLedBulb(LEDENETDevice):
 
     def _async_stop(self) -> None:
         """Shutdown the connection and mark unavailable."""
-        self.set_unavailable()
+        self.set_unavailable("Connection closed")
         if self._aio_protocol:
             self._aio_protocol.close()
         self._last_update_time = NEVER_TIME
@@ -309,34 +316,42 @@ class AIOWifiLedBulb(LEDENETDevice):
         """
         now = time.monotonic()
         assert self._protocol is not None
-        if not force and (self._last_update_time + PUSH_UPDATE_INTERVAL) > now:
-            if self.is_on:
+        if (
+            # If the device is not available from a previous disconnect
+            # fall through and try to reconnect send we do the
+            # _async_send_state_query
+            self.available
+            and not force
+            and (self._last_update_time + PUSH_UPDATE_INTERVAL) > now
+        ):
+            if self.is_on and self._protocol.state_push_updates:
                 # If the device pushes state updates when on
                 # then no need to poll except for the interval
                 # to make sure the device is still responding
-                if self._protocol.state_push_updates:
-                    self._async_raise_if_offline()
-                    return
+                return
             elif self._protocol.power_push_updates:
                 # If the device pushes power updates
                 # then no need to poll except for the interval
                 # to make sure the device is still responding
-                self._async_raise_if_offline()
                 return
         self._last_update_time = now
-        if self._updates_without_response == MAX_UPDATES_WITHOUT_RESPONSE:
+        if self._updates_without_response >= MAX_UPDATES_WITHOUT_RESPONSE:
             if self._aio_protocol:
                 self._aio_protocol.close()
-            self.set_unavailable()
-            self._updates_without_response = 0
-            raise RuntimeError(f"{self.ipaddr}: Bulb stopped responding")
-        await self._async_send_state_query()
-        self._updates_without_response += 1
+            self.set_unavailable(
+                f"device stopped responding after {MAX_UPDATES_WITHOUT_RESPONSE} requests to send state"
+            )
+            raise DeviceUnavailableException(
+                f"{self.ipaddr}: device stopped responding after {MAX_UPDATES_WITHOUT_RESPONSE} requests to send state"
+            )
+        try:
+            await self._async_send_state_query()
+        except asyncio.TimeoutError as ex:
+            raise DeviceUnavailableException(
+                f"{self.ipaddr}: timed out trying to connect after {self.timeout} seconds"
+            ) from ex
 
-    def _async_raise_if_offline(self) -> None:
-        """Raise RuntimeError if the bulb is offline."""
-        if not self.available:
-            raise RuntimeError(f"{self.ipaddr}: Bulb not responding, too soon to retry")
+        self._updates_without_response += 1
 
     async def async_set_levels(
         self,
@@ -599,7 +614,8 @@ class AIOWifiLedBulb(LEDENETDevice):
         async with self._get_time_lock:
             self._get_time_future = asyncio.Future()
             try:
-                await asyncio.wait_for(self._get_time_future, timeout=self.timeout)
+                async with asyncio_timeout(self.timeout):
+                    await self._get_time_future
             except asyncio.TimeoutError:
                 _LOGGER.warning("%s: Could not get time from the device", self.ipaddr)
                 return None
@@ -615,7 +631,8 @@ class AIOWifiLedBulb(LEDENETDevice):
         async with self._get_timers_lock:
             self._get_timers_future = asyncio.Future()
             try:
-                await asyncio.wait_for(self._get_timers_future, timeout=self.timeout)
+                async with asyncio_timeout(self.timeout):
+                    await self._get_timers_future
             except asyncio.TimeoutError:
                 _LOGGER.warning("%s: Could not get timers from the device", self.ipaddr)
                 return None
@@ -637,21 +654,19 @@ class AIOWifiLedBulb(LEDENETDevice):
 
     async def _async_connect(self) -> None:
         """Create connection."""
-        _, self._aio_protocol = await asyncio.wait_for(
-            self.loop.create_connection(  # type: ignore
+        async with asyncio_timeout(self.timeout):
+            _, self._aio_protocol = await self.loop.create_connection(  # type: ignore
                 lambda: AIOLEDENETProtocol(
                     self._async_data_recieved, self._async_connection_lost
                 ),
                 self.ipaddr,
                 self.port,
-            ),
-            timeout=self.timeout,
-        )
+            )
 
     def _async_connection_lost(self, exc: Optional[Exception]) -> None:
         """Called when the connection is lost."""
         self._aio_protocol = None
-        self.set_unavailable()
+        self.set_unavailable("Connection lost")
 
     def _async_data_recieved(self, data: bytes) -> None:
         """New data on the socket."""
@@ -691,7 +706,7 @@ class AIOWifiLedBulb(LEDENETDevice):
     def _async_process_message(self, msg: bytes) -> None:
         """Process a full message (maybe reassembled)."""
         assert self._protocol is not None
-        self.set_available()
+        self.set_available(f"Received message {msg.hex()}")
         prev_state = self.raw_state
         changed_state = False
         if self._protocol.is_valid_outer_message(msg):
@@ -833,14 +848,13 @@ class AIOWifiLedBulb(LEDENETDevice):
                 self._determine_protocol_future = asyncio.Future()
                 self._aio_protocol.write(protocol.construct_state_query())
                 try:
-                    await asyncio.wait_for(
-                        self._determine_protocol_future, timeout=self.timeout
-                    )
+                    async with asyncio_timeout(self.timeout):
+                        await self._determine_protocol_future
                 except asyncio.TimeoutError:
                     if self._aio_protocol:
                         self._aio_protocol.close()
                     continue
                 else:
                     return
-        self.set_unavailable()
-        raise RuntimeError(f"{self.ipaddr}: Cannot determine protocol")
+        self.set_unavailable("Cannot determine protocol")
+        raise DeviceUnavailableException(f"{self.ipaddr}: Cannot determine protocol")
